;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x0f54287075520e5d7156495c462a0954 . "./code.cg2js/cg-acache.fasl")
(#x79b8780b7de6ac269e0895b195886846 . "./code.cg2js/cg-base.fasl")
(#x233cc012dde790edaf9be42e9983eaf8 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x3eb2f5d45099db4fbbaf8201f7dc4106 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x6fc5d0ab8cb22d68fa839f795c2f12be . "./code.cg2js/cg-bitmap-stream.fasl")
(#x5486e9a487dca54b75d95de9e9a1c58f . "./code.cg2js/cg-button.fasl")
(#x0c372b39c7b8909187e1d824a51b809c . "./code.cg2js/cg-calendar.fasl")
(#x2b2efad00e093a2ef17bac9434d9fe9c . "./code.cg2js/cg-caret.fasl")
(#x139f709d924218aff403dac832960b10 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xf9c1a7c51ffbfd2bfff63333661026fb . "./code.cg2js/cg-chart-widget.fasl")
(#xb83ecf44e338fb9a1d7f9ebab535f22e . "./code.cg2js/cg-check-box.fasl")
(#x56b208d5573da0836722d9fb02d1bd60 . "./code.cg2js/cg-choice-list.fasl")
(#x89a93e861d4949ef6b44fe1e14fec827 . "./code.cg2js/cg-choose-printer.fasl")
(#x2c0ab2503ba539c0e9439c133804a1a3 . "./code.cg2js/cg-class-grid.fasl")
(#x0df827db1047d00429fed2175ee7079f . "./code.cg2js/cg-class-slot-grid.fasl")
(#x37076f3574f0f6906d7f25c616046529 . "./code.cg2js/cg-class-support.fasl")
(#xf031d8683d02bbc3207c4e34efa420ae . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x48321b13bcb65ff6f7377720a29babb2 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x6740819054574a85637c039894556de2 . "./code.cg2js/cg-clipboard.fasl")
(#x8a4dd7d68a6204d61dde800cc0ef395d . "./code.cg2js/cg-color-dialog.fasl")
(#x230313efecb98ae1d6f04af857262ef7 . "./code.cg2js/cg-combo-box.fasl")
(#x76faacb50132c38bbab3eb7436be7fb9 . "./code.cg2js/cg-common-control.fasl")
(#xf75a2f19d647463faa60e8f51cb8fd00 . "./code.cg2js/cg-comtab.fasl")
(#xb5c967eb2905f0e653d55641f68bff50 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xa91dc118e372614b1536d34ece7d3891 . "./code.cg2js/cg-curve.fasl")
(#xfb856477fcd0c06c46cff510eac875c2 . "./code.cg2js/cg-dde-utils.fasl")
(#x996d1ca98a887432ae312b0c641e2fe0 . "./code.cg2js/cg-dev.fasl")
(#x061b3518c25b1b9441c36ac5a041d70b . "./code.cg2js/cg-dialog-item.fasl")
(#xe1a3e698f9678fde8f83f89e60e3f05d . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x4d87df5e8f0307ab735198de04bb97c1 . "./code.cg2js/cg-directory-dialog.fasl")
(#xcd1bcfe564caf4bc83df9495f7344108 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xbc7bb20d85c65da9f8cbf3b460cf3a9c . "./code.cg2js/cg-drag-and-drop.fasl")
(#xa91885f4864f9a191a80da3321e703bf . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xf5bcf5e83f5f933e39512a030c5c8336 . "./code.cg2js/cg-drawable.fasl")
(#x7f9fc15ce25edbc215364c476c7210c9 . "./code.cg2js/cg-dropping-outline.fasl")
(#x3cfa868ad4746b589a6e7e7453e2b625 . "./code.cg2js/cg-edit-in-place.fasl")
(#x3ee2aad3d4fce73f2701f60d2574e9d8 . "./code.cg2js/cg-editable-text.fasl")
(#xc777a594d65469ed7427079721ecd8f8 . "./code.cg2js/cg-file-dialog.fasl")
(#x8b79e2d7f28e3138d116af0654253eb7 . "./code.cg2js/cg-fill-texture.fasl")
(#x27061235c45247c8ec57d0a3027ab8b3 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x053764defce9a1d2f2f248e608689067 . "./code.cg2js/cg-font-dialog.fasl")
(#x2dac59ca794dfc33b6fcb23ec1620ec0 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x3cc30add8e4dab36750a421830062b0e . "./code.cg2js/cg-get-pixmap.fasl")
(#xff74f1127556c9edfa64adfecaf642fa . "./code.cg2js/cg-get-position.fasl")
(#xd83f1ac03434637ef06048ab057c5490 . "./code.cg2js/cg-graphics-context.fasl")
(#x14e91094294ef62de8cb1a7da26396c3 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x4105f61221d6e53c5bd1d591ab106213 . "./code.cg2js/cg-grid-widget.fasl")
(#x2dd5f2cef8be7dd7b11f669d831aa7be . "./code.cg2js/cg-group-box.fasl")
(#x1271912e6421d252b2e16924cd0bd01a . "./code.cg2js/cg-header-control.fasl")
(#xfcb2af244213f185328ca08d1c87e19a . "./code.cg2js/cg-hotspot.fasl")
(#xb9fa199a9b8b222693462003a8a2ec9c . "./code.cg2js/cg-html-dialog.fasl")
(#x1f2ffba0f5b253ee83f8190567054f29 . "./code.cg2js/cg-html-widget.fasl")
(#xf556974b9ef56d5ed3fb81c05661cc07 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x2abed2557b22de57b7bb64cc1e5b38f6 . "./code.cg2js/cg-icon.fasl")
(#xa738cecd575749b0e26447496d1c99c9 . "./code.cg2js/cg-ie.fasl")
(#xd2c6016c8450fa5a1ecb176abc0fdf7f . "./code.cg2js/cg-intersect-posbox.fasl")
(#x15e0a01b37badca31e8ef3d5b03480c2 . "./code.cg2js/cg-intersect.fasl")
(#xa36cb12a9ecd29970f455304ec52736d . "./code.cg2js/cg-item-list.fasl")
(#x7d94f8b87b0d5210f98d94b227cb0ebe . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x678f498835132f1531f6baf6c367bb2a . "./code.cg2js/cg-lamp.fasl")
(#x47a3c3468c75f5fb52c2396f552ee887 . "./code.cg2js/cg-layout.fasl")
(#xcdffc0a0c5f0590c06702a42c1ba848d . "./code.cg2js/cg-lettered-menu.fasl")
(#x98077a59cf28e2aaadd15ea10b4ea293 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x59aa903d09fe2482db953fd88fb33538 . "./code.cg2js/cg-lisp-text.fasl")
(#x7661682fa5129de60cadef7201810fda . "./code.cg2js/cg-lisp-widget.fasl")
(#xb7dfd12c8ac9f9071be86af5b3c04d7e . "./code.cg2js/cg-list-view.fasl")
(#x410d1247fd0fd518f1d44ab549838faa . "./code.cg2js/cg-mci.fasl")
(#xd4206b61e67ac49ff7f5626fada71a39 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x26b9ce9d70de5b53f11fa67ac1fd0d2f . "./code.cg2js/cg-menu.fasl")
(#xdd311dd09d539b29adbb5164b0cfc0be . "./code.cg2js/cg-message-dialog.fasl")
(#x678c0c0893c1f884e065d200d091645b . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xf87a7f08c3881289b518d02d022a0a37 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x0f2a84b3df5d67d4be980c3f0b3abfbf . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x56b79bdd5b9681098432628a7a2b7dde . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x7b4ea1aba6ad75e835ff584b3ae92e1f . "./code.cg2js/cg-multi-picture-button.fasl")
(#x2c65a72c6bd3299ec1be8bf8c8077908 . "./code.cg2js/cg-nodes.fasl")
(#x4f0032808a4f043732099176c8abe1f0 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x0f5fc771b978d7ebcc5b1b09c6a54299 . "./code.cg2js/cg-object-editor.fasl")
(#xfe0d785888c80b6b243349f56ce07003 . "./code.cg2js/cg-ocx.fasl")
(#xfb883ec4818bfb3480e7ee37cefd7594 . "./code.cg2js/cg-os-widget.fasl")
(#xbb6b520750e58e1bef83cb362fe7475d . "./code.cg2js/cg-os-window.fasl")
(#x4ec76777143089259b585de76533cdd6 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x3e49b63810d62383852c0691aba6d926 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x21a502dcca62a56587b91a4600d1c6d6 . "./code.cg2js/cg-outline.fasl")
(#x903007c983c6984f88722c03c2ec750d . "./code.cg2js/cg-palette.fasl")
(#x4c3de3e93a8c196a47abd7f4c290896b . "./code.cg2js/cg-paren-matching.fasl")
(#xe08ce768e62a6b220ac314d3f643bd28 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xf3379aa492a8df0b7c87329ab54c1d0c . "./code.cg2js/cg-picture-widget.fasl")
(#xa940addd6d3fa2b218680410c42552e2 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x38f18642822052e6d25671f3a4b2ffdb . "./code.cg2js/cg-pixmap-printing.fasl")
(#x1bb5020e95f0bb00b9a9836ea80a2eb7 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xa1653018539f9ae955900abf28dd9054 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x2d33d0d59c605df9a808c949477c086f . "./code.cg2js/cg-pixmap.fasl")
(#x5c03abb5928fd051cdcc3f264d86edb7 . "./code.cg2js/cg-plot-widget.fasl")
(#x34d9d6a8d3e750943ac57b7e3b502a8a . "./code.cg2js/cg-printing.fasl")
(#x56d93a70f00ddec346b155eb56e12b26 . "./code.cg2js/cg-progress-indicator.fasl")
(#xae8dcd202752e993219a57588d2ed75d . "./code.cg2js/cg-project-window.fasl")
(#x3b3024ede9c64dae1cf34ff5b400ae47 . "./code.cg2js/cg-property.fasl")
(#xe6bee0d8437b81783c0bbda9426e927f . "./code.cg2js/cg-radio-button.fasl")
(#x472a8e4f56bd33e2936152f1900256d4 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xa185948debe0d5277d55d095cb677491 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x8777af0c52d41a91a80123e73323e2ae . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x517dc767d5bc05278e048b06d02546aa . "./code.cg2js/cg-rich-edit.fasl")
(#xe4aabaab666c9190521283e49214c19f . "./code.cg2js/cg-sample-file-menu.fasl")
(#x657701945770e83d8d174ea4f81a0387 . "./code.cg2js/cg-scaling-stream.fasl")
(#x2aeda8b8a103afec871b10c654053095 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x9d5530fd68c3f21bdac4a1aa5cf98fcd . "./code.cg2js/cg-scroll-bar.fasl")
(#x182a796d5b03c8a44132bb60b15b7fbc . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xc2cef35e2db85c75821bc730addcc8d7 . "./code.cg2js/cg-selected-object.fasl")
(#x5eab1366ea0e10713d9500e20e78addf . "./code.cg2js/cg-shortcut-menu.fasl")
(#x930bd62e8c1aa3e9ab3f526d8846a6cb . "./code.cg2js/cg-split-bar.fasl")
(#xe55cc110600bf75838666484f4cd0afc . "./code.cg2js/cg-static-text.fasl")
(#x8a0b86bf3f311445eaee3272f8e3b296 . "./code.cg2js/cg-status-bar.fasl")
(#x6eb00f7b6807d8d11ffeabc2b25ecd34 . "./code.cg2js/cg-string-dialog.fasl")
(#x4d2196acc75f098b6b438630a46196c2 . "./code.cg2js/cg-tab-control.fasl")
(#x681a40fccd87c577babb3e6a19465b33 . "./code.cg2js/cg-template-string.fasl")
(#xcb129223aba3037e2f7cdabcf3b8ee28 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x877afe8fe00073cc26f5a877635e578f . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x1af8992c1fcf9c41343c5d27a48709f3 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xb7a2929d388ac5fc7709cff02281ecc9 . "./code.cg2js/cg-text-or-combo.fasl")
(#x873a1581ea6599cda7ea17044e98ba1c . "./code.cg2js/cg-text-widget.fasl")
(#xc87fbba861107d1af7ea093054c7aee6 . "./code.cg2js/cg-timer.fasl")
(#x18ba8f67ee7508b97ac4a14026d869eb . "./code.cg2js/cg-toggling-widget.fasl")
(#x17a3d09417cb9f71efe997c693e6ff1d . "./code.cg2js/cg-toolbar.fasl")
(#x4a58c1166f273a36649630ccf921b186 . "./code.cg2js/cg-tooltip.fasl")
(#x4f1d79f5432f213303abe903e871978a . "./code.cg2js/cg-touch.fasl")
(#xa750aceab04ac08b28d1cfdd34211be5 . "./code.cg2js/cg-trackbar.fasl")
(#xa0dcdcbc6858695d3a9d39e20bd7970a . "./code.cg2js/cg-tray.fasl")
(#x30997263b929504c55d505ad3d1af21b . "./code.cg2js/cg-up-down-control.fasl")
(#x61d9caa93d08935231bfd92754f386d2 . "./code.cg2js/cg-utility-dialog.fasl")
(#x84ab7d98b38c53049ec52e0fe31eac5f . "./code.cg2js/cg-web-browser-dde.fasl")
(#xd85a957d2b84233f7de385a49745f139 . "./code.cg2js/cg-web-browser.fasl")
(#x17b5f09417b04b90b6983e91423135c0 . "./code.cg2js/cg-wrap-string.fasl")
(#x3f7bd1454267841ce0884d63fe654781 . "./code.cg2js/cg-yes-no-list.fasl")
(#xe739a12a413b1bd50ae5dbc576a70a2b . "./code.cg2js/cg-yes-no-string.fasl")
(#x7805ccbb7fc05a6283c07335fceae61f . "./code.cg2js/cg.fasl")
(#x4b89bfc1ef794fa5a4387a55b0bb9daf . "./code.idejs/ide-acache.fasl")
(#x61195d866c1b7e1845cf1cef42683192 . "./code.idejs/ide-apropos.fasl")
(#x780fa4dc4a17ecaccbccc66e015d31ab . "./code.idejs/ide-base.fasl")
(#x479de5ea6caad1bd011ddc252b98a875 . "./code.idejs/ide-class-browser.fasl")
(#x69d00714c8cb0195964d2040f643404a . "./code.idejs/ide-class-grapher.fasl")
(#xaac049ddac89ccee6fb13c15f0c08a23 . "./code.idejs/ide-clipboard.fasl")
(#x71d59d48607a24783cd57e8c80bd60dd . "./code.idejs/ide-dev.fasl")
(#x3741a56a6ee3f3f9062734fd0f123df2 . "./code.idejs/ide-editor.fasl")
(#x13676022660e00df177fc1e6cdb43c85 . "./code.idejs/ide-find-definitions.fasl")
(#x19b1c4a207eb1bf95edfd08b5eeaa8d3 . "./code.idejs/ide-find-in-files.fasl")
(#x20de301368a17460a1114336dc8d35bf . "./code.idejs/ide-form.fasl")
(#x879afbac02b3a274bdc6e4bb23204d42 . "./code.idejs/ide-grapher.fasl")
(#xac172570d7983e4237684d021d9ad46e . "./code.idejs/ide-inspector.fasl")
(#x5fea8e009666e2f94a7fcbf64dbd1792 . "./code.idejs/ide-intro.fasl")
(#xc43c62d112a28a1341d644a25b9f9adc . "./code.idejs/ide-keyshort.fasl")
(#xb459f0b7318fea8f89a0c654b71b7ae5 . "./code.idejs/ide-navigator.fasl")
(#x4a0698270cd6bb70850c1a2418166042 . "./code.idejs/ide-package-list.fasl")
(#xb2b15c452cdd759c674cda6f14bfdc00 . "./code.idejs/ide-patch-dialog.fasl")
(#x5544561803d00650408d3dcf1a2065c9 . "./code.idejs/ide-process-browser.fasl")
(#x8639f8108efd6ddbe75645b5c1d64b0c . "./code.idejs/ide-project.fasl")
(#x2c1c4b0e5c48b1fa21d2fc19f10c8b2d . "./code.idejs/ide-trace.fasl")
(#x9ea33eac9ca084d933e57fdcafa376f8 . "./code.idejs/ide-window-list.fasl")
(#x0b804e0d151b5efa34b768ac4ca38323 . "./code.idejs/ide.fasl")
(#xea5d13ce0f9a2cfde1ff539415770ab2 . "./cgjs.html")
(#xa0fd27890288fb85b9ee621ed47b2251 . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
